============================
Utilities
============================
PyDM comes with a set of utility methods ranging from simple replacement 
of protocol in a string, handling macro substitution in files, etc.

-------
General
-------
.. automodule:: pydm.utilities
   :members:

--------
Icons
--------
.. autoclass:: pydm.utilities.iconfont.IconFont
   :members:

--------
Macro
--------
.. automodule:: pydm.utilities.macro
   :members:

--------
Colors
--------
.. automodule:: pydm.utilities.colors
   :members:

--------
Units
--------
.. automodule:: pydm.utilities.units
   :members:
